@@ -353,7 +353,8 @@ GSS_CALLCONV gss_accept_delegation(
         major_status = globus_i_gsi_gss_create_cred(&local_minor_status,
                                                     GSS_C_BOTH,
                                                     delegated_cred_handle,
-                                                    &delegated_cred);
+                                                    &delegated_cred,
+                                                    GLOBUS_FALSE);
         if(GSS_ERROR(major_status))
         {
             globus_gsi_cred_handle_destroy(delegated_cred);
